@@ -706,6 +706,7 @@ xfce_notify_daemon_window_size_allocate(GtkWidget *widget,
     widget_screen = gtk_widget_get_screen (widget);
     display = gdk_screen_get_display (widget_screen);
     device_manager = gdk_display_get_device_manager (display);
+    pointer = gdk_device_manager_get_client_pointer (device_manager);
 #endif
 
     gdk_device_get_position (pointer, &p_screen, &x, &y);
@@ -1190,7 +1191,7 @@ static gboolean notify_notify (XfceNotifyGBus *skeleton,
     xfce_notify_window_set_do_fadeout(window, xndaemon->do_fadeout);
 
     if(value_hint_set)
-        xfce_notify_window_set_gauge_value(window, value_hint);
+        xfce_notify_window_set_gauge_value(window, value_hint, xndaemon->css_provider);
     else
         xfce_notify_window_unset_gauge_value(window);
 
